@@ -11,13 +11,21 @@ use Smart::Comments;
 use Bio::MUST::Core;
 use Bio::MUST::Core::Utils qw(secure_outfile);
 use aliased 'Bio::MUST::Core::Ali';
+use aliased 'Bio::MUST::Core::SeqMask';
 
 
 for my $infile (@ARGV_infiles) {
 
     ### Processing: $infile
     my $ali = Ali->load($infile);
-    $ali->idealize($ARGV_max_res_drop_site);
+
+    my $mask = SeqMask->ideal_mask($ali, $ARGV_max_res_drop_site);
+    $mask = $mask->codon_mask( {
+        frame => $ARGV_coding_frame,
+          max => $ARGV_codon_max_nt_drop,
+    } ) if $ARGV_keep_codons;
+    $ali->apply_mask($mask);
+
     my $outfile = secure_outfile($infile, $ARGV_out_suffix);
     $ali->store($outfile);
 }
@@ -32,7 +40,7 @@ idealize-ali.pl - Discard (nearly) gap-only sites from ALI files
 
 =head1 VERSION
 
-version 0.242020
+version 0.243430
 
 =head1 USAGE
 
@@ -65,6 +73,31 @@ are dropped.
 =for Euclid: n.type:    number
     n.default: 0
 
+=item --keep-codons
+
+When specified, this option forces the various applied masks to follow the
+codon structure [default: no]. This option only makes sense with nt seqs. See
+options C<--codon-max> and C<--coding-frame> for more control on this
+behavior.
+
+=item --codon-max[-nt-drop]=<n>
+
+Number of non-dropped nt sites allowed in a codon to be dropped [default: 1].
+Allowed values are 0, 1 and 2. To be used when the option C<--keep-codons> is
+also specified.
+
+=for Euclid: n.type:    integer, 0 <= n && n <= 2
+    n.default: 1
+
+=item --coding-frame=<n>
+
+Reading frame to be used when determining the ALI codon structure [default:
++1]. Allowed values are -3 to -1 and +1 to +3. To be used when the option
+C<--keep-codons> is also specified.
+
+=for Euclid: n.type:    integer, -3 <= n && n <= 3 && n != 0
+    n.default: +1
+
 =item --out[-suffix]=<suffix>
 
 Suffix to append to infile basenames for deriving outfile names [default:
